package models

import (
	"github.com/beego/beego/v2/client/orm"
	"html"
	"time"
)

const (
	BusinessConfCompanyName      = "CompanyName"
	BusinessConfCompanyWatermark = "CompanyWatermark"
	BusinessConfWatermarkChart   = "WatermarkChart"
)

// BusinessConf 商户配置表
type BusinessConf struct {
	Id         int    `orm:"column(id);pk"`
	ConfKey    string `description:"配置Key"`
	ConfVal    string `description:"配置值"`
	ValType    int    `description:"1-字符串；2-数值；3-字符串数组；4-富文本；"`
	Necessary  int    `description:"是否必填：0-否；1-是"`
	Remark     string `description:"备注"`
	CreateTime time.Time
}

// GetBusinessConf 获取商家配置
func GetBusinessConf() (list map[string]string, err error) {
	list = make(map[string]string)

	var items []*BusinessConf
	o := orm.NewOrm()
	sql := `SELECT * FROM business_conf`
	_, err = o.Raw(sql).QueryRows(&items)
	if err != nil {
		return
	}

	for _, v := range items {
		if v.ValType == 4 {
			list[v.ConfKey] = html.UnescapeString(v.ConfVal)
			continue
		}
		list[v.ConfKey] = v.ConfVal
	}
	return
}
